==> aws-java-sdk-1.7.1-sources.jar: com/amazonaws/services/cloudtrail/model/transform/S3BucketDoesNotExistExceptionUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cloudtrail.model.transform;

import com.amazonaws.AmazonServiceException;
import com.amazonaws.transform.JsonErrorUnmarshaller;
import com.amazonaws.util.json.JSONObject;

import com.amazonaws.services.cloudtrail.model.S3BucketDoesNotExistException;

public class S3BucketDoesNotExistExceptionUnmarshaller extends JsonErrorUnmarshaller {

    public S3BucketDoesNotExistExceptionUnmarshaller() {
        super(S3BucketDoesNotExistException.class);
    }

    public AmazonServiceException unmarshall(JSONObject json) throws Exception {
        // Bail out if this isn't the right error code that this
        // marshaller understands.
        String errorCode = parseErrorCode(json);
        if (errorCode == null || !errorCode.equals("S3BucketDoesNotExistException"))
            return null;

        S3BucketDoesNotExistException e = (S3BucketDoesNotExistException)super.unmarshall(json);

        return e;
    }
}

==> aws-java-sdk-1.7.4.2-sources.jar: com/amazonaws/services/cloudtrail/model/transform/S3BucketDoesNotExistExceptionUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cloudtrail.model.transform;

import com.amazonaws.AmazonServiceException;
import com.amazonaws.transform.JsonErrorUnmarshaller;
import com.amazonaws.util.json.JSONObject;

import com.amazonaws.services.cloudtrail.model.S3BucketDoesNotExistException;

public class S3BucketDoesNotExistExceptionUnmarshaller extends JsonErrorUnmarshaller {

    public S3BucketDoesNotExistExceptionUnmarshaller() {
        super(S3BucketDoesNotExistException.class);
    }

    @Override
    public boolean match(String errorTypeFromHeader, JSONObject json) throws Exception {
        if (errorTypeFromHeader == null) {
            // Parse error type from the JSON content if it's not available in the response headers
            String errorCodeFromContent = parseErrorCode(json);
            return (errorCodeFromContent != null && errorCodeFromContent.equals("S3BucketDoesNotExistException"));
        } else {
            return errorTypeFromHeader.equals("S3BucketDoesNotExistException");
        }
    }

    @Override
    public AmazonServiceException unmarshall(JSONObject json) throws Exception {
        S3BucketDoesNotExistException e = (S3BucketDoesNotExistException)super.unmarshall(json);
        e.setErrorCode("S3BucketDoesNotExistException");

        return e;
    }
}
